@@ -27,6 +27,7 @@ class TransformAuth:  # noqa: D
         self.__mql_server_url: Optional[str] = None
         self.__mql_client: Optional[MQLInterface] = None
         self.__auth_header: Optional[Dict[str, str]] = None
+        self.__api_key: Optional[str] = None
         self.config = ConfigHandler(override_config)
 
         # Overrides
@@ -38,8 +39,10 @@ class TransformAuth:  # noqa: D
     @property
     def api_key(self) -> Optional[str]:
         """Pull API key from config file by default, also supporting a fallback environment variable TRANSFORM_API_KEY."""
-        config_api_key = self.config._get_config_value(API_KEY_CONFIG_KEY)
-        return config_api_key if config_api_key else os.getenv("TRANSFORM_API_KEY")
+        if self.__api_key is None:
+            config_api_key = self.config._get_config_value(API_KEY_CONFIG_KEY)
+            return config_api_key if config_api_key else os.getenv("TRANSFORM_API_KEY")
+        return self.__api_key
 
     @api_key.setter
     def api_key(self, api_key: str) -> None:
@@ -50,6 +53,7 @@ class TransformAuth:  # noqa: D
         if not api_key.count("-") == 2:
             raise AuthException
 
+        self.__api_key = api_key
         self.config._set_config_value(API_KEY_CONFIG_KEY, api_key)
 
     @property
@@ -139,13 +143,14 @@ class TransformAuth:  # noqa: D
 
         Overrideable via passing MQL server url at instantiation process for users who need to redirect using a local proxy.
         """
-        return self.config._get_config_value(MQL_OVERRIDE_CONFIG_KEY)
+        return self.config._get_config_value(MQL_OVERRIDE_CONFIG_KEY) if self.config.override_config else None
 
     @mql_server_url_config_override.setter
     def mql_server_url_config_override(self, mql_server_url: str) -> None:  # noqa: D
         if not mql_server_url:
             self.config._remove_config_value(MQL_OVERRIDE_CONFIG_KEY)
         elif validators.url(mql_server_url, public=False):
+            self.__mql_server_url = mql_server_url
             self.config._set_config_value(MQL_OVERRIDE_CONFIG_KEY, mql_server_url)
         else:
             raise URLException(mql_server_url)
