@@ -103,7 +103,7 @@ class BaseInterface:
 
     @property
     def graphql_api_url(self) -> str:  # noqa: D
-        return f"{self.rest_api_url}/graphql"
+        return f"{self.rest_api_url.strip('/')}/graphql"
 
 
 class BackendInterface(BaseInterface):  # noqa: D
