@@ -29,8 +29,10 @@ from .interfaces import MQLInterface
 class MQLClient:
     """Wrapper that exposes MQLInterface and BackendInterface"""
 
-    def __init__(self, api_key: Optional[str] = None, mql_server_url: Optional[str] = None) -> None:  # noqa: D
-        self.context = TransformAuth(api_key, mql_server_url)
+    def __init__(  # noqa: D
+        self, api_key: Optional[str] = None, mql_server_url: Optional[str] = None, override_config: bool = True
+    ) -> None:
+        self.context = TransformAuth(api_key, mql_server_url, override_config)
 
     def create_query(  # noqa: D
         self,
